'''QuestionDialog - Screen displays a question label and buttons YES and NO.'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import clutter

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.transitions.transition import Transition
from entertainerlib.frontend.gui.widgets.justified_text_menu_item import (
    JustifiedTextMenuItem)
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.text_menu import TextMenu
from entertainerlib.frontend.user_event import UserEvent
from entertainerlib.utils.configuration import Configuration

class QuestionDialog(Screen):
    """
    QuestionDialog

    Dialog screen that contains question label and two buttons: yes and no.
    This is used when we want confirmation from the user for some operation.
    """

    def __init__(self, ui, data):
        """Create the layout of the screen

        @param data: Userdata [0]=screen, [1]=callback, [2]=question string
        """
        self.config = Configuration()
        Screen.__init__(self)

        self.ui = ui
        self.theme = self.config.theme
        self.current_screen = data[0]
        self.callback = data[1]

        #FIXME: Replace rect with beautiful cairo graphics
        rect = clutter.Rectangle()
        rect.set_color((0, 0, 0, 233))
        rect.set_size(740, 200)
        rect.set_position(280, 280)
        rect.show()
        self.add(rect)

        question = Label(0.04, "title", 0.22, 0.4, data[2])
        question.width = 0.5
        self.add(question)

        self.buttons = TextMenu(self.theme, self.config.show_effects())
        self.buttons.set_orientation(self.buttons.HORIZONTAL)
        self.buttons.set_item_size(350, 60)
        self.buttons.set_visible_column_count(2)

        # XXX: laymansterms - 0.26 is 355 px from default. As close to 350 as
        # this screen will get
        yes_button = JustifiedTextMenuItem(0.26, _("Yes"))
        yes_button.set_userdata("yes")
        self.buttons.add_actor(yes_button)

        no_button = JustifiedTextMenuItem(0.26, _("No"))
        no_button.set_userdata("no")
        self.buttons.add_actor(no_button)

        self.buttons.set_position(300, 380)
        self.buttons.set_active(True)
        self.buttons.show()
        self.add(self.buttons)

        self.show()

    def get_type(self):
        """Return screen type."""
        return Screen.DIALOG

    def get_name(self):
        """Return screen name (human readble)"""
        return "QuestionDialog"

    def handle_user_event(self, event):
        """ 
        Handle screen specific user events
        @param event: UserEvent object
        """
        event_type = event.get_type()

        if event_type == UserEvent.NAVIGATE_LEFT:
            self.buttons.move(self.buttons.LEFT)

        elif event_type == UserEvent.NAVIGATE_RIGHT:
            self.buttons.move(self.buttons.RIGHT)

        elif event_type == UserEvent.NAVIGATE_SELECT:
            if  self.buttons.get_current_menuitem().get_userdata() == "yes":
                self.callback()
                # This is not always possible
                self.ui.changeScreen(self.current_screen, Transition.BACKWARD)
            else:
                self.ui.changeScreen(self.current_screen, Transition.BACKWARD)

