'''VideoScreen - Screen allows user to browse video library content'''

__licence__ = "GPLv2"
__copyright__ = "2008, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import clutter

from entertainerlib.frontend.gui.screens.screen import Screen
from entertainerlib.frontend.gui.tabs.movies_tab import MoviesTab
from entertainerlib.frontend.gui.tabs.series_tab import SeriesTab
from entertainerlib.frontend.gui.tabs.video_clips_tab import VideoClipsTab
from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.tab_group import TabGroup
from entertainerlib.utils.configuration import Configuration

class VideoScreen(Screen):
    """
    VideoScreen

    This screen contains tabs for different video types. This is the top level
    UI for video library.
    """

    def __init__(self, ui, video_library):
        """Create the layout of the screen"""

        self.config = Configuration()
        Screen.__init__(self)

        self.ui = ui
        self.library = video_library

        # Screen Title (Displayed at the bottom left corner)
        screen_title = Label(0.13, "screentitle", 0, 0.87, _("Videos"))
        self.add(screen_title)

        # Tabs
        self.tab_group = TabGroup(0.95, 0.13, "title")
        tab1 = MoviesTab(ui, self.library, _("Movies"))
        tab2 = SeriesTab(ui, self.library, _("TV-Series"))
        tab3 = VideoClipsTab(ui, self.library, _("Video clips"))

        self.tab_group.add_tab(tab1)
        self.tab_group.add_tab(tab2)
        self.tab_group.add_tab(tab3)

        self.tab_group.set_y(self.ui.y(0.1))
        self.tab_group.set_anchor_point_from_gravity(clutter.GRAVITY_CENTER)
        self.tab_group.set_x(self.ui.x(0.5))
        self.tab_group.show()
        self.tab_group.set_active(True)
        self.add(self.tab_group)

        self.add(tab1)
        self.add(tab2)
        self.add(tab3)

        self.show()

    def get_type(self):
        """
        Get screen type.
        @return: Integer (Constant variable from Screen class)
        """
        return Screen.NORMAL

    def get_name(self):
        """
        Get screen name (human readable)
        @return: String
        """
        return "VideoScreen"

    def handle_user_event(self, event):   
        """ 
        Handle screen specific user events
        @param event: UserEvent object
        """
        self.tab_group.handle_user_event(event)

