'''Menuitem that contains a justified text label'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import pango
import clutter

from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.menu_item import MenuItem
from entertainerlib.utils.configuration import Configuration

class JustifiedTextMenuItem(MenuItem):
    """
    Simple menuitem widget that contains text label. Text is zoomed when
    menuitem is active.
    """
    # XXX: laymansterms - Justified is probably a misnomer now (although I'm
    # fairly convinced it wasn't justifying anything anyway). I'd rename to
    # TextMenuItem, but there is a namespace clash right now.

    def __init__(self, x_percent, text):
        """Initialize menuitem widget."""

        MenuItem.__init__(self)
        self.config = Configuration()
        self.theme = self.config.theme
        self.active_text_color = self.theme.getColor("menuitem_active")
        self.inactive_text_color = self.theme.getColor("menuitem_inactive")

        label = Label(0.037, "menuitem_inactive", 0, 0, text, "text_label")
        label.set_ellipsize(pango.ELLIPSIZE_END)
        label.width = x_percent

        self.add(label)

    def set_active(self, boolean):
        """
        Set menuitem active or inactive. Changes the text color of the
        menuitem.

        @param boolean: use True to set active and False to set inactive
        """
        MenuItem.set_active(self, boolean)
        if boolean:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.active_text_color)
                    actor.font_size = 0.05
        else:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.inactive_text_color)
                    actor.font_size = 0.037

