'''Simple menuitem that contains a text label (and optionl extras)'''

__licence__ = "GPLv2"
__copyright__ = "2007, Lauri Taimila"
__author__ = "Lauri Taimila <lauri@taimila.com>"

import pango
import clutter

from entertainerlib.frontend.gui.widgets.label import Label
from entertainerlib.frontend.gui.widgets.menu_item import MenuItem

class TextMenuItem(MenuItem):
    """
    Simple menuitem widget that contains text label.
    """

    OFFSET = 0.015

    def __init__(self, x_percent, y_percent, label_text, extra_text=None):
        """Initialize menuitem widget."""

        MenuItem.__init__(self)
        self.theme = self.config.theme

        self.active_text_color = self.theme.getColor("menuitem_active")
        self.inactive_text_color = self.theme.getColor("menuitem_inactive")

        font_size = 0.47 * y_percent

        # Create a rect to ensure that any background selector will span the
        # full length of the item and text won't be scaled and show jaggies
        rect = clutter.Rectangle()
        rect.set_size(
            self.get_abs_x(x_percent),
            self.get_abs_y(y_percent))
        self.add(rect)

        # Set label text
        try:
            first_line = label_text[:label_text.index('\n')]
        except ValueError:
            first_line = label_text
        label = Label(font_size, "menuitem_inactive", 0, 0, first_line,
            "text_label")
        label.set_ellipsize(pango.ELLIPSIZE_END)
        label.position = (self.OFFSET, (y_percent - label.height) / 2)
        self.add(label)

        # Set extra text
        if extra_text is not None:
            extra = Label(font_size, "menuitem_inactive", 0, 0, extra_text,
                "text_label")
            extra.position = (x_percent - extra.width - self.OFFSET,
                (y_percent - label.height) / 2)
            self.add(extra)

            label.width = x_percent - extra.width - (self.OFFSET * 2.5)
        else:
            label.width = x_percent - (self.OFFSET * 2)

    def set_active(self, boolean):
        """
        Set menuitem active or inactive. Changes the text color of the
        menuitem.

        @param boolean: use True to set active and False to set inactive
        """
        MenuItem.set_active(self, boolean)
        if boolean:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.active_text_color)
        else:
            for index in range(self.get_n_children()):
                actor = self.get_nth_child(index)
                if actor.get_name() == "text_label":
                    actor.set_color(self.inactive_text_color)

