'Tests Configuration'
# pylint: disable-msg=W0403

__license__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import os

from helpers import TestCommon

from entertainerlib.utils.configuration import Configuration
from entertainerlib.utils.theme import Theme

class ConfigurationTest(TestCommon):
    '''Test for utils.configuration'''

    def setUp(self):
        '''Set up the test'''
        TestCommon.setUp(self)

        self.config = Configuration(cfg_dir=self.test_dir)

    def tearDown(self):
        '''Clean up after the test'''
        TestCommon.tearDown(self)

    def testCreate(self):
        """Test correct Configuration initialization"""
        self.assertTrue(isinstance(self.config, Configuration))

    def testCreateDir(self):
        '''Test Configuration object directory creation'''
        self.assertTrue(os.path.exists(self.test_dir))

    def testBorg(self):
        '''Test that configuration objects share state'''
        self.second_config = Configuration()
        self.assertTrue(self.second_config.__dict__ is self.config.__dict__)

    def testGetStageWidth(self):
        '''Test getting the stage width'''
        self.assertEqual(self.config.get_stage_width(), 1366)

    def testSetStageWidth(self):
        '''Test setting the stage width'''
        new_width = 1600
        self.config.set_stage_width(new_width)
        self.assertEqual(self.config.get_stage_width(), new_width)

    def testGetStageHeight(self):
        '''Test getting the stage height'''
        self.assertEqual(self.config.get_stage_height(), 768)

    def testSetStageHeight(self):
        '''Test setting the stage height'''
        new_height = 900
        self.config.set_stage_height(new_height)
        self.assertEqual(self.config.get_stage_height(), new_height)

    def testGetVerticalOffset(self):
        '''Test getting the vertical offset'''
        self.config.set_stage_height(11)
        self.config.set_stage_width(16)
        self.assertEqual(self.config.get_vertical_offset(), 1)

    def testGetCfgDir(self):
        """Test getting the cfg dir"""
        self.assertEqual(self.config.get_cfg_dir(), self.test_dir)

    def testSetCfgDir(self):
        """Test setting the cfg dir"""
        new_dir = '~'
        # set_cfg_dir expands the path before assignment
        expanded_dir = os.path.expanduser(new_dir)
        self.config.set_cfg_dir(new_dir)
        self.assertEqual(self.config.get_cfg_dir(), expanded_dir)

    def testIsNotificationsEnabled(self):
        """Test getting the display_notifications boolean"""
        self.assertTrue(self.config.is_notifications_enabled())

    def testTrayIconEnabled(self):
        """Test getting the display_icon boolean"""
        self.assertFalse(self.config.tray_icon_enabled())

    def testWriteContentValue(self):
        """Test writing a value to the content configuration file"""
        new_value = "Gaithersburg,Maryland"
        self.config.write_content_value("Weather", "location", new_value)
        self.config.update_configuration()
        self.assertEqual(self.config.get_weather_location(), new_value)

    def testWritePreferenceValue(self):
        """Test writing a value to the preference configuration file"""
        new_value = True
        self.config.write_preference_value("General", "display_icon", new_value)
        self.config.update_configuration()
        self.assertEqual(self.config.tray_icon_enabled(), new_value)

    def testGetThemeName(self):
        """Test getting the current theme name"""
        current_name = "Default"
        self.assertEqual(self.config.get_theme_name(), current_name)

    def testStartAutoServer(self):
        """Test getting the start_auto_server boolean"""
        self.assertTrue(self.config.start_auto_server())

    def testGetSlideshowStep(self):
        '''Test getting the slideshow step'''
        self.assertEqual(self.config.get_slideshow_step(), 5)

