'''Test for backend.core.db.connection'''

__license__ = 'GPLv2'
__copyright__ = 'Paul Hummer'
__author__ = 'Paul Hummer <paul.hummer@canonical.com>'

import os
import sys
import unittest

from storm.locals import Store

from entertainerlib.backend.core.db.connection import Database, SCHEMA
from entertainerlib.tests import TestWithDatabase

class DatabaseTest(TestWithDatabase):
    '''Test for backend.core.db.connection'''

    def setUp(self):
        self.init()

    def _checkValidDatabase(self, storage):
        '''Checks the Store to make sure it has a valid database'''

        store = Store(storage)
        for table in SCHEMA.iterkeys():
            store.execute('SELECT * FROM `%s`' % table.lower())
        return True

    def testCreate(self):
        '''Test the creation of a new database'''

        storage = Database(self.filename)

        self.assertTrue(os.path.exists(self.filename))
        self.assertTrue(self._checkValidDatabase(storage))

    def testUseExisting(self):
        '''Test the connection to an existing database'''

        storage_file = self.data_dir + '/media'
        self.assertTrue(os.path.exists(storage_file))
        storage = Database(storage_file)
        self.assertTrue(self._checkValidDatabase(storage))

