'''Tests Music'''
# pylint: disable-msg=W0403

__licence__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

from pysqlite2 import dbapi2 as sqlite

from helpers import TestCommon

from entertainerlib.utils.configuration import Configuration

class TestMusic(TestCommon):
    """This test class sets up the test database required for all test
    classes that need to access the music cache"""

    def setUp(self):
        """See unittest.TestCase"""
        TestCommon.setUp(self)
        self.config = Configuration(self.test_dir)

        self.debug = False
        # The location of album art is required for some tests
        self.art_path = self.config.ALBUM_ART_DIR

        self.connection = sqlite.connect(self.config.MUSIC_DB)
        self.cursor = self.connection.cursor()
        self.cursor.execute("""CREATE TABLE track(
                            filename TEXT,
                            title VARCHAR(255),
                            artist VARCHAR(255),
                            album VARCHAR(255),
                            tracknumber INTEGER,
                            bitrate INTEGER,
                            year INTEGER,
                            rating INTEGER DEFAULT NULL,
                            length INTEGER,
                            genre VARCHAR(128),
                            comment TEXT,
                            lyrics TEXT DEFAULT "",
                            PRIMARY KEY(filename))""")
        # Populate the test database with enough information to make it useful
        for i in range(2):
            for j in range(2):
                for k in range(2):
                    sum = i + j + k # to get unique track numbers for ablums
                    db_row = ('/filename/%s' % str(i) + str(j) + str(k),
                              'title%s' % str(i) + str(j),
                              'artist0',
                              'album%d' % j,
                              'genre%d' % i,
                              i + j + k, # length
                              sum, # tracknumber
                              i, # bitrate
                              'comment%d' % i,
                              i  # year
                              )
                    self.cursor.execute("""INSERT INTO track(filename,
                                                             title,
                                                             artist,
                                                             album,
                                                             genre,
                                                             length,
                                                             tracknumber,
                                                             bitrate,
                                                             comment,
                                                             year)
                                        VALUES(?,?,?,?,?,?,?,?,?,?)""", db_row)

        self.cursor.execute("""CREATE TABLE playlist(
                            title TEXT,
                            PRIMARY KEY(title))""")

        self.cursor.execute("""CREATE TABLE playlist_relation(
                            title TEXT,
                            filename TEXT,
                            PRIMARY KEY(title, filename))""")
        self.connection.commit()

    def tearDown(self):
        """Clean up after the test"""
        TestCommon.tearDown(self)

