"""Tests Texture"""
# pylint: disable-msg=W0403

__license__ = "GPLv2"
__copyright__ = "2008, Matt Layman"
__author__ = "Matt Layman <laymansterms.dev@gmail.com>"

import os

import clutter
from gtk.gdk import Pixbuf

from helpers import TestCommon

from entertainerlib.frontend.gui.widgets.base import Base
from entertainerlib.frontend.gui.widgets.texture import Texture

THIS_DIR = os.path.dirname(__file__)

class TextureTest(TestCommon):
    """Test for entertainerlib.frontend.gui.widgets.texture"""

    def setUp(self):
        """Set up the test"""
        TestCommon.setUp(self)

        self.filename = os.path.join(THIS_DIR, 'data/ImageThumbnailer/test.jpg')

        self.texture = Texture(self.filename, 0.1, 0.2, test_dir=self.test_dir)

    def tearDown(self):
        """Clean up after the test"""
        TestCommon.tearDown(self)

    def testCreate(self):
        """Test correct Texture initialization"""
        self.assertTrue(isinstance(self.texture, (Base, clutter.Texture)))

    def testPosition(self):
        """Test the position property"""
        self.assertEqual(self.texture.position, (0.1, 0.2))

        self.texture.position = (0.4, 0.5)
        self.assertEqual(self.texture.position, (0.4, 0.5))

        self.texture._set_position((0.3, 0.6))
        self.assertEqual(self.texture._get_position(), (0.3, 0.6))

    def testGoodPixbuf(self):
        """Test setting the pixbuf with a good filename"""
        self.assertTrue(isinstance(self.texture.get_pixbuf(), Pixbuf))

    def testBadPixbuf(self):
        """Test setting the pixbuf to something with a bogus filename and a
        file that isn't an image"""
        filename = '/matts/bogus/path'
        texture1 = Texture(filename, 0.2, 0.3, test_dir=self.test_dir)
        self.assertEqual(texture1.get_pixbuf(), None)

        # Known file that won't be an image type
        filename = __file__
        texture2 = Texture(filename, 0.3, 0.4, test_dir=self.test_dir)
        self.assertEqual(texture2.get_pixbuf(), None)

    def testNoInitPosition(self):
        """Test that a texture will be displayed at the origin of the display
        area if no initial position is given"""
        no_pos_texture = Texture(self.filename)
        self.assertEqual(no_pos_texture.position, (0, 0))

