'''Test the thumbnailer abstract class'''
# pylint: disable-msg=W0403

import os

from helpers import TestCommon

from entertainerlib.utils import thumbnailer

THIS_DIR = os.path.dirname(__file__)

class ThumbnailerTest(TestCommon):
    '''Test the thumbnailer abstract class'''

    def setUp(self):
        '''See unittest.TestCase'''
        TestCommon.setUp(self)
        self.debug = False

    def tearDown(self):
        """Clean up after the test"""
        TestCommon.tearDown(self)

    def testValidThumbnailType(self):
        '''Test creating thumbnails with a valid type'''
        thumbnailer_image = thumbnailer.Thumbnailer(
            THIS_DIR + '/data/ImageThumbnailer/test.jpg', 'image',
            test_dir=self.test_dir)
        self.assertTrue(isinstance(thumbnailer_image, thumbnailer.Thumbnailer))

        thumbnailer_video = thumbnailer.Thumbnailer(
            THIS_DIR + '/data/VideoThumbnailer/test.avi', 'video',
            test_dir=self.test_dir)
        self.assertTrue(isinstance(thumbnailer_video, thumbnailer.Thumbnailer))

        thumbnailer_recording = thumbnailer.Thumbnailer(
            THIS_DIR + '/data/VideoThumbnailer/test.avi', 'recording',
            test_dir=self.test_dir)
        self.assertTrue(isinstance(thumbnailer_recording,
            thumbnailer.Thumbnailer))

    def testInvalidThumbnailType(self):
        '''Test creating thumbnails with an invalid type'''
        self.assertRaises(thumbnailer.ThumbnailerException,
            thumbnailer.Thumbnailer,
            THIS_DIR + '/data/ImageoThumbnailer/test.jpg', 'alskdjfhg',
            test_dir=self.test_dir)

    def testValidFileToThumbnail(self):
        '''Test image file thumbnailing'''
        thumbnailer_image = thumbnailer.Thumbnailer(
            THIS_DIR + '/data/ImageThumbnailer/test.jpg', 'image',
            test_dir=self.test_dir)
        self.assertTrue(isinstance(thumbnailer_image, thumbnailer.Thumbnailer))

    def testInvalidFileToThumbnail(self):
        '''Test thumbnailing of a non-existent file'''
        self.assertRaises(thumbnailer.ThumbnailerException,
            thumbnailer.Thumbnailer,
            THIS_DIR + '/data/ImageThumbnailer/alskdjfhg.jpg',
            'image', test_dir=self.test_dir)

    def testAbstractCreateThumbnailer(self):
        '''Tests trying to create the abstract thumbnailer'''
        thumbnailer_test = thumbnailer.Thumbnailer(
            THIS_DIR + '/data/ImageThumbnailer/test.jpg', 'image',
            test_dir=self.test_dir)
        self.assertRaises(Exception, thumbnailer_test.create_thumbnail)

