'''Tests VideoThumbnailer'''
# pylint: disable-msg=W0403

import os

from helpers import TestCommon

from entertainerlib.utils.video_thumbnailer import (
    VideoThumbnailer, VideoThumbnailerException)
from entertainerlib.utils.thumbnailer import ThumbnailerException

THIS_DIR = os.path.dirname(__file__)

class VideoThumbnailerTest(TestCommon):
    '''Tests VideoThumbnailer'''

    def setUp(self):
        """See unittest.TestCase"""
        TestCommon.setUp(self)
        self.debug = False

    def tearDown(self):
        """Clean up after the test"""
        TestCommon.tearDown(self)

    def testThumbnailerConstructor(self):
        '''Tests instantiation of thumbnailer class'''
        self.thumbnailer = VideoThumbnailer(
            THIS_DIR + '/data/VideoThumbnailer/test.avi', src='video',
            test_dir=self.test_dir)
        self.assertTrue(isinstance(self.thumbnailer, VideoThumbnailer))

    def testThumbnailerConstructorFilenameIsFolder(self):
        '''Tests proper handling of folders instead of files'''
        self.assertRaises(ThumbnailerException,
            VideoThumbnailer, os.path.abspath('.'), test_dir=self.test_dir)

    def testThumbnailerConstructorFilenameExists(self):
        '''Tests existence of file to thumbnail'''
        self.assertRaises(ThumbnailerException,
            VideoThumbnailer, os.path.abspath('foo-bar-baz'),
            test_dir=self.test_dir)

    def testThumbnailerConstructorSrc(self):
        '''Tests valid source types'''
        self.assertRaises(ThumbnailerException,
            VideoThumbnailer, os.path.abspath('.') +
            '/data/VideoThumbnailer/test.avi', src="foo",
            test_dir=self.test_dir)

    def testThumbnailAvi(self):
        '''Tests thumbnailing of Avi file'''
        thumbnailer = VideoThumbnailer(
            THIS_DIR + '/data/VideoThumbnailer/test.avi', src='video',
            test_dir=self.test_dir)
        if os.path.exists(thumbnailer._thumb_file):
            os.remove(thumbnailer._thumb_file)
        thumbnailer.create_thumbnail()
        if self.debug:
            print 'Expecting thumbnail : %s' % (self.thumbnailer._thumb_file)
        self.assertTrue(os.path.exists(thumbnailer._thumb_file))

    def testThumbnailFlv(self):
        '''Tests thumbnailing of a flash file'''
        thumbnailer = VideoThumbnailer(
            THIS_DIR + '/data/VideoThumbnailer/test.avi', src='video',
            test_dir=self.test_dir)
        if os.path.exists(thumbnailer._thumb_file):
            os.remove(thumbnailer._thumb_file)
        thumbnailer.create_thumbnail()
        if self.debug:
            print 'Expecting thumbnail : %s' % (self.thumbnailer._thumb_file)
        self.assertTrue(os.path.exists(thumbnailer._thumb_file))

