'''Test helper classes and functions'''
# pylint: disable-msg=W0231

import unittest
import os
import shutil

from random import random
from math import floor

THIS_DIR = os.path.dirname(__file__)

from entertainerlib.frontend.backend_connection import BackendConnection

class MockBackendConnection(BackendConnection):
    '''Mock BackendConnection'''

    def __init__(self):
        '''Stub constructor'''

    def close_connection(self):
        '''See BackendConnection'''

class TestCommon(unittest.TestCase):
    """Common test harness to provide random directory"""

    def setUp(self):
        '''Set up the test

        Creates a temporary directory name for each test
        '''

        rand_id = floor(random() * 1000)
        self.test_dir = os.path.join(THIS_DIR, '%s' % rand_id,)

        try:
            shutil.rmtree(self.test_dir)
        except OSError:
            pass

    def tearDown(self):
        '''Clean up after the test'''
        if os.path.exists(self.test_dir):
            shutil.rmtree(self.test_dir)

