#!/usr/bin/env python
'''distutils installation script'''

from distutils.core import setup
from glob import glob
import os


def find_files(dirs, dest_root='local/share'):
    '''Walk files and directories and return them in a form for data_files'''
    # pylint: disable-msg=W0621
    result = []
    if isinstance(dirs, str):
        dirs = [dirs]
    for dir in dirs:
        for root, dirs, files in os.walk(dir):
            dest = os.path.join(dest_root, root)
            source_files = [os.path.join(root, file) for file in files]
            result.append((dest, source_files))
    return result



entertainer_packages = []
for root, dirs, files in os.walk('entertainerlib'):
    if 'tests' in root or 'glade' in root:
        continue
    entertainer_packages.append(root)

package_data = [
    'frontend/glade/*',
    'utils/glade/*',
    ]

data_files = find_files('cfg', 'local/share/entertainer')
data_files.extend(find_files('icons'))
data_files.extend(find_files('locale'))
data_files.append(
    ('local/share/entertainer/docs', [
        'docs/LICENSE',
        'docs/COPYING',
        'docs/EXIF_LICENSE',
        'docs/DEPENDENCIES',
        ]))
data_files.append(
    ('local/share/applications', ['docs/entertainer.desktop']))

setup(
    name='Entertainer',
    version='0.2a',
    description='Entertainer Media Center',
    url='http://www.launchpad.net/entertainer',
    license='GPL',
    packages=entertainer_packages,
    package_data={'entertainerlib': package_data},
    scripts=['entertainer', 'entertainer-backend',
        'entertainer-content-manager', 'entertainer-preferences',],
    data_files=data_files,
    long_description='''
        Entertainer aims to be a simple and easy-to-use media center solution
        for Gnome and XFce desktop environments. Entertainer is written
        completely in Python using object-oriented programming paradigm.
        It uses the gstreamer multimedia framework for multimedia playback.
        The user Interface is implemented with Clutter UI-library, which
        creates sleek OpenGL animated user interfaces. Entertainer also uses
        other great projects like SQLite and iNotify for caching media
        libraries.''',
    )

