#!/usr/bin/env python
'''Debugger'''
# pylint: disable-msg=C0111
# XXX: rockstar - If we are to continue using this tool, it needs to be
# documented (add docstrings)

__licence__ = "GPLv2"
__copyright__ = "2008, Joshua Scotton"
__author__ = "Joshua Scotton <josh@joshuascotton.com>"

import os
import string
import sys
import ConfigParser

from ConfigParser import ParsingError
from pysqlite2 import dbapi2 as sqlite

PARENT_DIR = os.path.dirname(__file__)
sys.path += [PARENT_DIR + '/..']

from entertainerlib.utils.configuration import Configuration

class ShowDebug:
    '''Debug'''

    def __init__(self):

        self.config = Configuration()

        # Config File
        self.config_file = os.path.join(self.config.get_cfg_dir(),
            'content.conf')
        #initialise configparser file
        self.configparser = ConfigParser.ConfigParser()
        try:
            self.configparser.readfp(open(self.config_file))
        except:
            print "Error with content.conf in FeedConfigToolsTest setUp()"
            sys.exit(1)

    def get_feed_list(self):
        feeds = []
        connection = sqlite.connect(self.config.FEED_DB)
        cursor = connection.cursor()
        cursor.execute("SELECT url FROM feed ORDER BY url")
        for row in cursor:
            feeds.append(row[0])
        connection.close()
        return feeds

    def get_feed_list_from_config(self):
        return self.configparser.get("RSS", "feeds").split(';')

    def get_videoclip_list(self):
        connection = sqlite.connect(self.config.VIDEO_DB)
        cursor = connection.cursor()
        cursor.execute("""SELECT filename
                          FROM   metadata
                          WHERE  type='CLIP'
                          ORDER BY title""")
        clips = []
        for row in cursor:
            clips.append(row[0])
        connection.close()
        return clips

    def get_movie_list(self):
        connection = sqlite.connect(self.config.VIDEO_DB)
        cursor = connection.cursor()
        cursor.execute("""SELECT videofile.filename
                          FROM   videofile, metadata
                          WHERE  type='MOVIE'
                          AND    videofile.filename=metadata.filename
                          ORDER BY title""")
        movies = []
        for row in cursor:
            movies.append(row[0])
        connection.close()
        return movies

    def get_episode_list(self):
        connection = sqlite.connect(self.config.VIDEO_DB)
        cursor = connection.cursor()
        cursor.execute("""SELECT filename
                          FROM   metadata
                          WHERE  type='TV-SERIES'
                          ORDER BY title""")
        episodes = []
        for row in cursor:
            episodes.append(row[0])
        connection.close()
        return episodes

    def get_image_list(self):
        connection = sqlite.connect(self.config.IMAGE_DB)
        cursor = connection.cursor()
        cursor.execute("""SELECT filename
                          FROM   image
                          ORDER BY filename""")
        images = []
        for row in cursor:
            images.append(row[0])
        connection.close()
        return images

    def get_album_list(self):
        connection = sqlite.connect(self.config.MUSIC_DB)
        cursor = connection.cursor()
        cursor.execute("SELECT DISTINCT album FROM track ORDER BY album")
        albums = []
        for row in cursor:
            albums.append(row[0])
        connection.close()
        return albums

    def get_track_list(self):
        connection = sqlite.connect(self.config.MUSIC_DB)
        cursor = connection.cursor()
        cursor.execute("""SELECT filename
                          FROM   track
                          ORDER BY filename""")
        tracks = []
        for row in cursor:
            tracks.append(row[0])
        connection.close()
        return tracks

    def print_list(self, list):
        ret_val = "[\n"
        for item in list:
            ret_val += "\""+str(item)+"\"\n"
        print ret_val + "]"



    def run_debug(self, verbose=False):
        if not os.path.exists(self.config.VIDEO_DB):
            raise Exception("Video database doesn't exist!")
        if not os.path.exists(self.config.MUSIC_DB):
            raise Exception("Music database doesn't exist!")
        if not os.path.exists(self.config.IMAGE_DB):
            raise Exception("Image database doesn't exist!")
        if not os.path.exists(self.config.FEED_DB):
            raise Exception("Feed database doesn't exist!")

        feeds = self.get_feed_list()
        images = self.get_image_list()
        tracks = self.get_track_list()
        albums = self.get_album_list()
        clips = self.get_videoclip_list()
        movies = self.get_movie_list()
        episodes = self.get_episode_list()

        print "### Number of Feeds:        ", len(feeds)
        if verbose:
            self.print_list(feeds)
        if len(feeds) <> len(self.get_feed_list_from_config()):
            print ("Number of feeds in db (" + len(feeds) +
                ") doesn't match number of feeds in config (", +
                len(self.get_feed_list_from_config()) + ")!")
        print "### Number of Images:       ", len(images)
        if verbose:
            self.print_list(images)
        print "### Number of Music Tracks: ", len(tracks)
        if verbose:
            self.print_list(tracks)
        print "### Number of Music Albums: ", len(albums)
        if verbose:
            self.print_list(albums)
        print "### Number of VideoClips:   ", len(clips)
        if verbose:
            self.print_list(clips)
        print "### Number of Movies:       ", len(movies)
        if verbose:
            self.print_list(movies)
        print "### Number of Episodes:     ", len(episodes)
        if verbose:
            self.print_list(episodes)

ShowDebug().run_debug()
